==> SimplyDualWielding-6.0.5%2B1.20.%282-4%29-Fabric-sources.jar: eva/dualwielding/network/ListPacket.java <==
package eva.dualwielding.network;

import net.fabricmc.fabric.api.networking.v1.FabricPacket;
import net.fabricmc.fabric.api.networking.v1.PacketType;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_7923;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.function.Function;


public record ListPacket(int[] rawIds) implements FabricPacket {

    public static final class_2960 LIST_PACKET_ID = class_2960.method_43902("eva", "list");

    public static PacketType<ListPacket> TYPE = PacketType.create(LIST_PACKET_ID, new Function<class_2540, ListPacket>() {
        @Override
        public ListPacket apply(class_2540 buf) {
            return new ListPacket(read(buf));
        }
    });

    public ListPacket(List<String> ids) {
        this(asIntArray(ids));
    }

    private static int[] read(class_2540 buf) {
        List<Integer> rawIds = new ArrayList<>();
        while (buf.readableBytes() >= 4)
            rawIds.add(buf.readInt());
        int[] ids = new int[rawIds.size()];
        for (int i = 0; i < rawIds.size(); i++)
            ids[i] = rawIds.get(i);
        return ids;
    }

    public void write(class_2540 buf) {
        buf.method_52986(buf.maxCapacity());
        int i;
        for (i = 0; buf.writableBytes() >= 4 && i < rawIds.length; i++) {
            buf.method_53002(rawIds[i]);
        }
        buf.method_52986(buf.writerIndex());
    }

    @Override
    public PacketType<?> getType() {
        return TYPE;
    }

    private static int[] asIntArray(List<String> ids) {
        int[] rawIds = new int[ids.size()];
        for (int i = 0; i < ids.size(); i++) {
            if (Objects.equals(ids.get(i), ""))
                rawIds[i] = 0;
            else
                rawIds[i] = class_7923.field_41178.method_10206(class_7923.field_41178.method_10223(class_2960.method_12829(ids.get(i))));
        }
        return rawIds;
    }

    private static List<String> asStringList(int[] rawIds) {
        List<String> ids = new ArrayList<>();
        for (int rawId : rawIds) {
            if (rawId == 0)
                ids.add("");
            else
                ids.add(class_7923.field_41178.method_10221(class_7923.field_41178.method_10200(rawId)).toString());
        }
        return ids;
    }

    public List<String> getList() {
        return asStringList(rawIds);
    }

}

==> SimplyDualWielding-6.1.2%2B1.21.%282-4%29-Fabric-sources.jar: eva/dualwielding/network/ListPacket.java <==
package eva.dualwielding.network;

import eva.dualwielding.DualWieldingServer;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_7923;
import net.minecraft.class_8710;
import net.minecraft.class_9139;

public record ListPacket(int[] rawIds) implements class_8710 {
    public static final class_9154<ListPacket> ID = new class_9154<>(DualWieldingServer.LIST_PACKET_ID);
    public static final class_9139<class_2540, ListPacket> CODEC = class_8710.method_56484(ListPacket::write, ListPacket::new);

    private ListPacket(class_2540 buf) {
        this(read(buf));
    }

    public ListPacket(List<String> ids) {
        this(asIntArray(ids));
    }

    private static int[] read(class_2540 buf) {
        List<Integer> rawIds = new ArrayList<>();
        while (buf.readableBytes() >= 4)
            rawIds.add(buf.readInt());
        int[] ids = new int[rawIds.size()];
        for (int i = 0; i < rawIds.size(); i++)
            ids[i] = rawIds.get(i);
        return ids;
    }

    private void write(class_2540 buf) {
        buf.method_52986(buf.maxCapacity());
        int i;
        for (i = 0; buf.writableBytes() >= 4 && i < rawIds.length; i++) {
            buf.method_53002(rawIds[i]);
        }
        buf.method_52986(buf.writerIndex());
    }

    private static int[] asIntArray(List<String> ids) {
        int[] rawIds = new int[ids.size()];
        for (int i = 0; i < ids.size(); i++) {
            if (Objects.equals(ids.get(i), ""))
                rawIds[i] = 0;
            else
                rawIds[i] = class_7923.field_41178.method_10206(class_7923.field_41178.method_63535(class_2960.method_60654(ids.get(i))));
        }
        return rawIds;
    }

    private static List<String> asStringList(int[] rawIds) {
        List<String> ids = new ArrayList<>();
        for (int rawId : rawIds) {
            if (rawId == 0)
                ids.add("");
            else
                ids.add(class_7923.field_41178.method_10221(class_7923.field_41178.method_10200(rawId)).toString());
        }
        return ids;
    }

    public List<String> getList() {
        return asStringList(rawIds);
    }

    @Override
    public @NotNull class_9154<? extends class_8710> method_56479() {
        return ID;
    }

}
